highlight module
================

.. automodule:: whoosh.highlight

See :doc:`how to highlight terms in search results </highlight>`.

Fragmenters
-----------

.. autofunction:: NullFragmenter

.. autoclass:: SimpleFragmenter

.. autoclass:: SentenceFragmenter

.. autoclass:: ContextFragmenter

Scorers
-------

.. autofunction:: BasicFragmentScorer

Formatters
----------

.. autoclass:: UppercaseFormatter
    
.. autoclass:: GenshiFormatter

Utility classes
---------------

.. autoclass:: Fragment
    :members: